@@ -18,7 +18,7 @@ import os
 import time
 
 _this_year = time.strftime("%Y")
-__version__ = "0.1"
+__version__ = "0.1.1"
 __author__ = "Nicki Skafte Detlefsen et al."
 __author_email__ = "nsde@dtu.dk"
 __license__ = "Apache-2.0"
@@ -33,3 +33,5 @@ _logger.setLevel(python_logging.INFO)
 
 PACKAGE_ROOT = os.path.dirname(__file__)
 PROJECT_ROOT = os.path.dirname(PACKAGE_ROOT)
+
+__all__ = []
